The hardware and bandwidth for this mirror is donated by dogado GmbH, the Webhosting and Full Service-Cloud Provider. Check out our Wordpress Tutorial.
If you wish to report a bug, or if you are interested in having us mirror your free-software or open-source project, please feel free to contact us at mirror[@]dogado.de.

Package {CPHazard}


Title: Hazard Change Point Models for Different Lifetime Distributions
Version: 0.1.0
Description: Estimates the parameters of models with a single change-point in the hazard rate for time-to-event data. Supported models include the exponential (Gijbels & Gürler (2003) <doi:10.1023/B:LIDA.0000012424.71723.9d>, Matthews & Farewell (1982) <doi:10.2307/2530460>), Exponential-Lindley (Joshi & Rattihalli (2020) <doi:10.1007/978-981-15-5414-8_29>), Lindley (Joshi, Jose, & Bhati (2016) <doi:10.1080/03610918.2015.1096381>), log-logistic (Nadar, Upadhyay, & Joshi (2025) <doi:10.3390/math13091457>), and Weibull (Williams & Kim (2013) <doi:10.1080/03610926.2011.600505>) hazard change-point models. Provides functions for generating random variates and evaluating the probability density function (PDF) and the cumulative distribution function (CDF) of the fitted change-point models. Includes Kaplan-Meier and Nelson-Aalen diagnostic plots, together with goodness-of-fit measures such as the Akaike Information Criterion (AIC), the Bayesian Information Criterion (BIC), distance metrics such as the L1-norm and L2-norm, and the Kolmogorov-Smirnov (K-S) statistic for model evaluation.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (≥ 4.1.0)
Imports: lamW, survival, EnvStats
Maintainer: Vasudha Upadhyay <vasudhyay@gmail.com>
Suggests: spelling
Language: en-US
NeedsCompilation: no
Packaged: 2026-09-16 11:02:37 UTC; Keerthan Aithal
Author: Vasudha Upadhyay [aut, cre], Dr. Savitri Joshi [aut, cph], Keerthan Aithal [aut]
Repository: CRAN
Date/Publication: 2026-09-27 16:30:29 UTC

Density for the Exponential Hazard Change-Point Model

Description

Computes the PDF of the exponential hazard change-point model with parameters theta1, theta2, and tau.

Usage

dee(x, theta1, theta2, tau)

Arguments

x

Numeric vector of survival times (must be >= 0).

theta1

Rate parameter of the pre-change-point exponential regime; must be > 0.

theta2

Rate parameter of the post-change-point exponential regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of densities, the same length as x.

References

Gijbels, I., & Gürler, Ü. (2003). Estimation of a change point in a Hazard Function Based on Censored Data. Lifetime Data Analysis, 9(4), 395–411. doi:10.1023/B:LIDA.0000012424.71723.9d

Matthews, D. E., & Farewell, V. T. (1982). On Testing for a Constant Hazard against a change point Alternative. Biometrics, 38(2), 463-468. doi:10.2307/2530460

See Also

Other exponential hazard change-point model functions: est_ee(), pee(), ree()

Examples

dee(x = c(1, 2), theta1 = 1, theta2 = 2, tau = 1.25)

Density for the Exponential-Lindley Hazard Change-Point Model

Description

Computes the PDF of the Exponential-Lindley hazard change-point model with parameters theta1, theta2, and tau.

Usage

del(x, theta1, theta2, tau)

Arguments

x

Numeric vector of survival times (must be >= 0).

theta1

Rate parameter of the pre-change-point exponential regime; must be > 0.

theta2

Scale parameter of the post-change-point Lindley regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of densities, the same length as x.

References

Joshi, S., & Rattihalli, R. N. (2020, October). Estimation of parameters in the Exponential-Lindley hazard change-point model. In Proceedings of International Conference on Trends in Computational and Cognitive Engineering: TCCE 2019 , 345–356.doi:10.1007/978-981-15-5414-8_29

See Also

Other Exponential-Lindley hazard change-point model functions: est_el(), pel(), rel()

Examples

del(x = c(0.5, 1, 2), theta1 = 0.3, theta2 = 0.5, tau = 1)

Density for the Log-Logistic Hazard Change-Point Model

Description

Computes the PDF of the log-logistic hazard change-point model with parameters theta1, theta2, and tau.

Usage

dlgl(x, theta1, theta2, tau)

Arguments

x

Numeric vector of survival times (must be >= 0).

theta1

Scale parameter of the pre-change-point log-logistic regime; must be > 0.

theta2

Scale parameter of the post-change-point log-logistic regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of densities, the same length as x.

References

Nadar, S. S., Upadhyay, V., & Joshi, S. (2025). Detecting Clinical Risk Shift Through log–logistic Hazard Change-Point Model. Mathematics, 13(9), 1457. doi:10.3390/math13091457

See Also

Other log-logistic hazard change-point functions: est_lgl(), plgl(), rlgl()

Examples

dlgl(x = c(0.5, 1, 2), theta1 = 0.3, theta2 = 0.5, tau = 1)

Density for the Lindley Hazard Change-Point Model

Description

Computes the PDF of the Lindley hazard change-point model with parameters theta1, theta2, and tau.

Usage

dlin(x, theta1, theta2, tau)

Arguments

x

Numeric vector of survival times (must be >= 0).

theta1

Scale parameter of the pre-change-point Lindley regime; must be > 0.

theta2

Scale parameter of the post-change-point Lindley regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of densities, the same length as x.

References

Joshi, S., Jose, K. K. and Bhati, D. (2016). Estimation of a Change Point in the Hazard Rate of Lindley Model under Right Censoring. Communications in Statistics - Simulation and Computation. 46(5), 3563–3574. doi:10.1080/03610918.2015.1096381

See Also

Other Lindley hazard change-point model functions: est_lin(), plin(), rlin()

Examples

dlin(x = c(0.5, 1, 2), theta1 = 1, theta2 = 2, tau = 1.25)

Density for the Weibull Hazard Change-Point Model

Description

Computes the PDF of the Weibull hazard change-point model with parameters theta1, theta2, tau, and k.

Usage

dww(x, theta1, theta2, tau, k)

Arguments

x

Numeric vector of survival times (must be >= 0).

theta1

Scale parameter of the pre-change-point Weibull regime; must be > 0.

theta2

Scale parameter of the post-change-point Weibull regime; must be > 0.

tau

Change-point parameter; must be > 0.

k

Shape parameter (constant); must be > 0.

Value

A numeric vector of densities, the same length as x.

References

M. R. Williams and D. Y. Kim. A test for an abrupt change in Weibull Hazard Functions with Staggered Entry and Type I Censoring. Communications in Statistics - Theory and Methods, 42(11): 1922–1933, 2013. doi:10.1080/03610926.2011.600505.

See Also

Other Weibull hazard change-point model functions: est_ww(), pww(), rww()

Examples

dww(x = c(0.5, 1, 2), theta1 = 1, theta2 = 3, tau = 0.5, k = 2)

Parameter Estimation for the Exponential Hazard Change-Point Model

Description

Estimates theta1, theta2, and tau from time-to-event data (xi and di) under the exponential hazard change-point model , and produces goodness-of fit criteria (AIC and BIC) , the distance metrics (L1-Norm, L2-Norm, K-S Statistic) and the Kaplan-Meier / Nelson-Aalen diagnostic plots against the fitted model.

Usage

est_ee(xi, di)

Arguments

xi

Numeric vector of observed times (must be >= 0). Requires at least 5 uncensored observations.

di

Numeric vector of event indicators (1 = event, 0 = censored). Defaults to all events if omitted.

Value

A list containing Estimates (the fitted theta1, theta2, tau), DiagnosticMeasures (L1-Norm, L2-Norm, K-S Statistic, AIC, BIC), and plot (Kaplan-Meier and Nelson-Aalen plots)

References

Gijbels, I., & Gürler, Ü. (2003). Estimation of a change point in a Hazard Function Based on Censored Data. Lifetime Data Analysis, 9(4), 395–411. doi:10.1023/B:LIDA.0000012424.71723.9d

Matthews, D. E., & Farewell, V. T. (1982). On Testing for a Constant Hazard against a change point Alternative. Biometrics, 38(2), 463-468. doi:10.2307/2530460

See Also

Other exponential hazard change-point model functions: dee(), pee(), ree()

Examples

# Demonstration 1 (Parameter estimation with missing di)
est_ee(xi=c(45,32,40,21,12,13,52,60))

# Demonstration 2 (Parameter estimation with (xi,di))
n <- 100
x <- ree(n, 1, 2, 1.25)
d <- sample(c(0,1), n, replace = TRUE, prob = c(0.2, 0.8))
est_ee(xi = x, di = d)

Parameter Estimation for the Exponential-Lindley Hazard Change-Point Model

Description

Estimates theta1, theta2, and tau from time-to-event data (xi and di) under the Exponential-Lindley hazard change-point model with single change-point in hazard, and produces Kaplan-Meier / Nelson-Aalen diagnostic plots for the fitted model.

Usage

est_el(xi, di)

Arguments

xi

Numeric vector of observed times (must be >= 0). Requires at least 5 uncensored observations.

di

Numeric vector of event indicators (1 = event, 0 = censored). Defaults to all events if omitted.

Value

A list containing ParameterEstimates (the fitted theta1, theta2, tau), DiagnosticMeasures (L1-Norm, L2-Norm, K-S Statistic, AIC, BIC), and plot (Kaplan-Meier and Nelson-Aalen plots).

References

Joshi, S., & Rattihalli, R. N. (2020, October). Estimation of parameters in the Exponential-Lindley hazard change-point model. In Proceedings of International Conference on Trends in Computational and Cognitive Engineering: TCCE 2019 , 345–356.doi:10.1007/978-981-15-5414-8_29

See Also

Other Exponential-Lindley hazard change-point model functions: del(), pel(), rel()

Examples

# Demonstration 1 (Parameter estimation with missing di)
est_el(xi=c(45,32,45,22,12,13,78,99))

# Demonstration 2 (Parameter estimation with (xi,di))
x <- rel(n = 50, theta1 = 1.5, theta2 = 0.2, tau = 1.5)
d <- sample(c(0, 1), 50, replace = TRUE, prob = c(0.2, 0.8))
est_el(xi = x, di = d)

Parameter Estimation for the Log-Logistic Hazard Change-Point Model

Description

Estimates theta1, theta2, and tau from time-to-event data (xi and di) under the log-logistic hazard change-point model , and produces goodness-of fit criteria (AIC and BIC) , the distance metrics (L1-Norm, L2-Norm, K-S Statistic) and the Kaplan-Meier / Nelson-Aalen diagnostic plots against the fitted model.

Usage

est_lgl(xi, di)

Arguments

xi

Numeric vector of observed times (must be >= 0). Requires at least 5 uncensored observations.

di

Numeric vector of event indicators (1 = event, 0 = censored). Defaults to all events if omitted.

Value

A list containing ParameterEstimates (the fitted theta1, theta2, tau), DiagnosticMeasures (L1-Norm, L2-Norm, K-S Statistic, AIC, BIC), and plot (Kaplan-Meier and Nelson-Aalen plots).

References

Nadar, S. S., Upadhyay, V., & Joshi, S. (2025). Detecting Clinical Risk Shift Through log–logistic Hazard Change-Point Model. Mathematics, 13(9), 1457. doi:10.3390/math13091457

See Also

Other log-logistic hazard change-point functions: dlgl(), plgl(), rlgl()

Examples

# Demonstration 1 (Parameter estimation with missing di)
est_lgl(x=c(45,32,45,22,12,13,78,99))

# Demonstration 2 (Parameter estimation with (xi,di))
x <- rlgl(n = 50, theta1 = 1.5, theta2 = 0.5, tau = 2)
d <- sample(c(0, 1), 50, replace = TRUE, prob = c(0.2, 0.8))
est_lgl(xi = x, di = d)

Parameter Estimation for the Lindley Hazard Change-Point Model

Description

Estimates theta1, theta2, and tau from time-to-event data (xi and di) under the Lindley hazard change-point model , and produces goodness-of fit criteria (AIC and BIC) , the distance metrics (L1-Norm, L2-Norm, K-S Statistic) and the Kaplan-Meier / Nelson-Aalen diagnostic plots against the fitted model.

Usage

est_lin(xi, di)

Arguments

xi

Numeric vector of observed times (must be >= 0). Requires at least 5 uncensored observations.

di

Numeric vector of event indicators (1 = event, 0 = censored). Defaults to all events if omitted.

Value

A list containing ParameterEstimates (the fitted theta1, theta2, tau), DiagnosticMeasures (L1-Norm, L2-Norm, K-S Statistic, AIC, BIC), and plot (Kaplan-Meier and Nelson-Aalen plots).

References

Joshi, S., Jose, K. K. and Bhati, D. (2016). Estimation of a Change Point in the Hazard Rate of Lindley Model under Right Censoring. Communications in Statistics - Simulation and Computation. 46(5), 3563–3574. doi:10.1080/03610918.2015.1096381

See Also

Other Lindley hazard change-point model functions: dlin(), plin(), rlin()

Examples

# Demonstration 1 (Parameter estimation with missing di)
est_lin(xi=c(22,12,15,25,10,13,30,9))

# Demonstration 2 (Parameter estimation with (xi,di))
n <- 100
x <- rlin(n, 1, 2, 1.25)
d <- sample(c(0,1), n, replace = TRUE, prob = c(0.2, 0.8))
est_lin(xi = x, di = d)

Parameter Estimation for the Weibull Hazard Change-Point Model

Description

Estimates theta1, theta2, tau, and k from time-to-event data (xi and di) under the Weibull hazard change-point model , and produces goodness-of fit criteria (AIC and BIC) , the distance metrics (L1-Norm, L2-Norm, K-S Statistic) and the Kaplan-Meier / Nelson-Aalen diagnostic plots against the fitted model.

Usage

est_ww(xi, di = NULL)

Arguments

xi

Numeric vector of observed times (must be >= 0). Requires at least 5 uncensored observations.

di

Numeric vector of event indicators (1 = event, 0 = censored). Defaults to all events if omitted.

Value

A list containing ParameterEstimates (the fitted theta1, theta2, tau, k), DiagnosticMeasures (L1-Norm, L2-Norm, K-S Statistic, AIC, BIC), and plot (Kaplan-Meier and Nelson-Aalen plots).

References

M. R. Williams and D. Y. Kim. A test for an abrupt change in Weibull Hazard Functions with Staggered Entry and Type I Censoring. Communications in Statistics - Theory and Methods, 42(11): 1922–1933, 2013. doi:10.1080/03610926.2011.600505.

See Also

Other Weibull hazard change-point model functions: dww(), pww(), rww()

Examples

# Demonstration 1 (Parameter estimation with missing di)
est_ww(xi=c(12,8,45,7,47,32,14,10,19,23))

# Demonstration 2 (Parameter estimation with (xi,di))
x <- rww(n = 50, theta1 = 1, theta2 = 3, tau = 0.5, k = 3)
d <- sample(c(0, 1), 50, replace = TRUE, prob = c(0.2, 0.8))
est_ww(xi = x, di = d)

Distribution Function for the Exponential Hazard Change-Point Model

Description

Computes the CDF of the exponential hazard change-point model with parameters theta1, theta2, and tau.

Usage

pee(x, theta1, theta2, tau)

Arguments

x

Numeric vector of survival times (must be >= 0).

theta1

Rate parameter of the pre-change-point exponential regime; must be > 0.

theta2

Rate parameter of the post-change-point exponential regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of probabilities, the same length as x.

References

Gijbels, I., & Gürler, Ü. (2003). Estimation of a change point in a Hazard Function Based on Censored Data. Lifetime Data Analysis, 9(4), 395–411. doi:10.1023/B:LIDA.0000012424.71723.9d

Matthews, D. E., & Farewell, V. T. (1982). On Testing for a Constant Hazard against a change point Alternative. Biometrics, 38(2), 463-468. doi:10.2307/2530460

See Also

Other exponential hazard change-point model functions: dee(), est_ee(), ree()

Examples

pee(x = c(0.5, 1, 2), theta1 = 1, theta2 = 2, tau = 1.25)

Distribution Function for the Exponential-Lindley Hazard Change-Point Model

Description

Computes the CDF of the Exponential-Lindley hazard change-point model with parameters theta1, theta2, and tau.

Usage

pel(x, theta1, theta2, tau)

Arguments

x

Numeric vector of survival times (must be >= 0).

theta1

Rate parameter of the pre-change-point exponential regime; must be > 0.

theta2

Shape parameter of the post-change-point Lindley regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of probabilities, the same length as x.

References

Joshi, S., & Rattihalli, R. N. (2020, October). Estimation of parameters in the Exponential-Lindley hazard change-point model. In Proceedings of International Conference on Trends in Computational and Cognitive Engineering: TCCE 2019 , 345–356.doi:10.1007/978-981-15-5414-8_29

See Also

Other Exponential-Lindley hazard change-point model functions: del(), est_el(), rel()

Examples

pel(x = c(0.5, 1, 2), theta1 = 0.3, theta2 = 0.5, tau = 1)

Distribution Function for the Log-Logistic Hazard Change-Point Model

Description

Computes the CDF of the log-logistic hazard change-point model with parameters theta1, theta2, and tau.

Usage

plgl(x, theta1, theta2, tau)

Arguments

x

Numeric vector of survival times (must be >= 0).

theta1

Scale parameter of the pre-change-point log-logistic regime; must be > 0.

theta2

Scale parameter of the post-change-point log-logistic regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of probabilities, the same length as xi.

References

Nadar, S. S., Upadhyay, V., & Joshi, S. (2025). Detecting Clinical Risk Shift Through log–logistic Hazard Change-Point Model. Mathematics, 13(9), 1457. doi:10.3390/math13091457

See Also

Other log-logistic hazard change-point functions: dlgl(), est_lgl(), rlgl()

Examples

plgl(x = c(0.5, 1, 2), theta1 = 0.3, theta2 = 0.5, tau = 1)

Distribution Function for the Lindley Hazard Change-Point Model

Description

Computes the CDF of the Lindley hazard change-point model with parameters theta1, theta2, and tau.

Usage

plin(x, theta1, theta2, tau)

Arguments

x

Numeric vector of survival times (must be >= 0).

theta1

Scale parameter of the pre-change-point Lindley regime; must be > 0.

theta2

Scale parameter of the post-change-point Lindley regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of probabilities, the same length as x.

References

Joshi, S., Jose, K. K. and Bhati, D. (2016). Estimation of a Change Point in the Hazard Rate of Lindley Model under Right Censoring. Communications in Statistics - Simulation and Computation. 46(5), 3563–3574. doi:10.1080/03610918.2015.1096381

See Also

Other Lindley hazard change-point model functions: dlin(), est_lin(), rlin()

Examples

plin(x = c(0.5, 1, 2), theta1 = 1, theta2 = 2, tau = 1.25)

Distribution Function for the Weibull Hazard Change-Point Model

Description

Computes the CDF of the Weibull hazard change-point model with parameters theta1, theta2, tau, and k.

Usage

pww(x, theta1, theta2, tau, k)

Arguments

x

Numeric vector of survival times (must be >= 0).

theta1

Scale parameter of the pre-change-point Weibull regime; must be > 0.

theta2

Scale parameter of the post-change-point Weibull regime; must be > 0.

tau

Change-point parameter; must be > 0.

k

Shape parameter (constant); must be > 0.

Value

A numeric vector of probabilities, the same length as x.

References

M. R. Williams and D. Y. Kim. A test for an abrupt change in Weibull Hazard Functions with Staggered Entry and Type I Censoring. Communications in Statistics - Theory and Methods, 42(11): 1922–1933, 2013. doi:10.1080/03610926.2011.600505.

See Also

Other Weibull hazard change-point model functions: dww(), est_ww(), rww()

Examples

pww(x = c(0.5, 1, 2), theta1 = 1, theta2 = 3, tau = 0.5, k = 2)

Random Number Generation for the Exponential Hazard Change-Point Model

Description

Generates random survival times for the exponential hazard change-point model with parameters theta1, theta2, and tau.

Usage

ree(n, theta1, theta2, tau)

Arguments

n

Sample size.

theta1

Rate parameter of the pre-change-point exponential regime; must be > 0.

theta2

Rate parameter of the post-change-point exponential regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of length n of random survival times.

References

Gijbels, I., & Gürler, Ü. (2003). Estimation of a change point in a Hazard Function Based on Censored Data. Lifetime Data Analysis, 9(4), 395–411. doi:10.1023/B:LIDA.0000012424.71723.9d

Matthews, D. E., & Farewell, V. T. (1982). On Testing for a Constant Hazard against a change point Alternative. Biometrics, 38(2), 463-468. doi:10.2307/2530460

See Also

Other exponential hazard change-point model functions: dee(), est_ee(), pee()

Examples

ree(n = 100, theta1 = 1, theta2 = 0.5, tau = 1.25)


Random Number Generation for the Exponential-Lindley Hazard Change-Point Model

Description

Generates random survival times for the Exponential-Lindley hazard change-point model with parameters theta1, theta2, and tau.

Usage

rel(n, theta1, theta2, tau)

Arguments

n

Sample size.

theta1

Rate parameter of the pre-change-point exponential regime; must be > 0.

theta2

Shape parameter of the post-change-point Lindley regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of length n of random survival times.

References

Joshi, S., & Rattihalli, R. N. (2020, October). Estimation of parameters in the Exponential-Lindley hazard change-point model. In Proceedings of International Conference on Trends in Computational and Cognitive Engineering: TCCE 2019 , 345–356.doi:10.1007/978-981-15-5414-8_29

See Also

Other Exponential-Lindley hazard change-point model functions: del(), est_el(), pel()

Examples

rel(n = 100, theta1 = 1.5, theta2 = 0.2, tau = 5)

Random Number Generation for the Log-Logistic Hazard Change-Point Model

Description

Generates random survival times for the log-logistic hazard change-point model with parameters theta1, theta2, and tau.

Usage

rlgl(n, theta1, theta2, tau)

Arguments

n

Sample size.

theta1

Scale parameter of the pre-change-point log-logistic regime; must be > 0.

theta2

Scale parameter of the post-change-point log-logistic regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of length n of random survival times

References

Nadar, S. S., Upadhyay, V., & Joshi, S. (2025). Detecting Clinical Risk Shift Through log–logistic Hazard Change-Point Model. Mathematics, 13(9), 1457. doi:10.3390/math13091457

See Also

Other log-logistic hazard change-point functions: dlgl(), est_lgl(), plgl()

Examples

rlgl(n = 100, theta1 = 1.5, theta2 = 0.2, tau = 5)

Random Number Generation for the Lindley Hazard Change-Point Model

Description

Generates random survival times for the Lindley hazard change-point model with parameters theta1, theta2, and tau.

Usage

rlin(n, theta1, theta2, tau)

Arguments

n

Sample size.

theta1

Scale parameter of the pre-change-point Lindley regime; must be > 0.

theta2

Scale parameter of the post-change-point Lindley regime; must be > 0.

tau

Change-point parameter; must be > 0.

Value

A numeric vector of length n of random survival times.

References

Joshi, S., Jose, K. K. and Bhati, D. (2016). Estimation of a Change Point in the Hazard Rate of Lindley Model under Right Censoring. Communications in Statistics - Simulation and Computation. 46(5), 3563–3574. doi:10.1080/03610918.2015.1096381

See Also

Other Lindley hazard change-point model functions: dlin(), est_lin(), plin()

Examples

rlin(n = 100, theta1 = 1, theta2 = 2, tau = 1.25)

Random Number Generation for the Weibull Hazard Change-Point Model

Description

Generates random survival times for the Weibull hazard change-point model with parameters theta1, theta2, tau, and k.

Usage

rww(n, theta1, theta2, tau, k)

Arguments

n

Sample size.

theta1

Scale parameter of the pre-change-point Weibull regime; must be > 0.

theta2

Scale parameter of the post-change-point Weibull regime; must be > 0.

tau

Change-point parameter; must be > 0.

k

Shape parameter (constant); must be > 0.

Value

A numeric vector of length n of random survival times.

References

M. R. Williams and D. Y. Kim. A test for an abrupt change in Weibull Hazard Functions with Staggered Entry and Type I Censoring. Communications in Statistics - Theory and Methods, 42(11): 1922–1933, 2013. doi:10.1080/03610926.2011.600505.

See Also

Other Weibull hazard change-point model functions: dww(), est_ww(), pww()

Examples

rww(n = 100, theta1 = 1, theta2 = 3, tau = 0.5, k = 2)

These binaries (installable software) and packages are in development.
They may not be fully stable and should be used with caution. We make no claims about them.
Health stats visible at Monitor.